@@ -68,7 +68,7 @@
     if (!"remotes" %in% rownames(installed.packages(lib.loc))) {
         if (is.null(lib.loc))
             lib.loc <- .libPaths()
-        stop(
+        .stop(
             "package 'remotes' not installed in library path(s)",
             "\n    ", paste(lib.loc, collapse="\n    "),
             "\ninstall with 'install(\"remotes\")'",
@@ -79,7 +79,7 @@
     tryCatch({
         loadNamespace("remotes", lib.loc)
     }, error=function(e) {
-        stop(
+        .stop(
             "'loadNamespace(\"remotes\")' failed:",
             "\n    ", conditionMessage(e)
         )
@@ -95,7 +95,7 @@
     if (length(doing)) {
         pkgNames <- paste(.sQuote(doing), collapse=", ")
         .message("Installing package(s) %s", pkgNames)
-        install.packages(pkgs = doing, lib = lib, repos = repos, ...)
+        .inet_install.packages(pkgs = doing, lib = lib, repos = repos, ...)
     }
     setdiff(pkgs, doing)
 }
@@ -131,7 +131,10 @@
 }
 
 .install_n_invalid_pkgs <- function(valid) {
-    sum(nrow(valid$too_new), nrow(valid$out_of_date))
+    if (isTRUE(valid))
+        0L
+    else
+        sum(nrow(valid$too_new), nrow(valid$out_of_date))
 }
 
 .install_ask_up_or_down_grade <-
@@ -164,9 +167,9 @@
 }
 
 .install_update <-
-    function(repos, ask, lib.loc = NULL, instlib = NULL, checkBuilt = TRUE, ...)
+    function(repos, ask, lib.loc = NULL, instlib = NULL, checkBuilt, ...)
 {
-    old_pkgs <- old.packages(lib.loc, repos, checkBuilt = checkBuilt)
+    old_pkgs <- .inet_old.packages(lib.loc, repos, checkBuilt = checkBuilt)
     if (is.null(old_pkgs))
         return()
 
@@ -190,31 +193,22 @@
         ask <- answer == "s"
     }
 
-    update.packages(
+    .inet_update.packages(
         lib.loc, repos, oldPkgs = old_pkgs, ask = ask, instlib = instlib
     )
 }
 
 .install_updated_version <-
-    function(valid, update, repos, ask, ...)
+    function(valid, update, repos, ...)
 {
-    pkgs <- c(rownames(valid$too_new), rownames(valid$out_of_date))
+    if (isTRUE(valid))
+        return(valid)
+    else
+        pkgs <- c(rownames(valid$too_new), rownames(valid$out_of_date))
+
     if (is.null(pkgs) || !update)
         return(pkgs)
 
-    if (ask) {
-        answer <- .getAnswer(
-            sprintf(
-                "reinstall %d packages for Bioconductor version %s? [y/n]: ",
-                length(pkgs), version()
-            ),
-            allowed = c("y", "Y", "n", "N")
-        )
-
-        if (answer == "n")
-            return(pkgs)
-    }
-
     .install(pkgs, repos, ...)
     pkgs
 }
@@ -277,6 +271,9 @@
 #'     prompting, to pick packages to update, or to cancel updating
 #'     (in a non-interactive session, no packages will be updated
 #'     unless `ask = FALSE`).
+#' @param checkBuilt `logical(1)`. If `TRUE` a package built under an
+#'     earlier major.minor version of R (e.g., 3.4) is considered to
+#'     be old.
 #' @param version `character(1)` _Bioconductor_ version to install,
 #'     e.g., `version = "3.8"`. The special symbol `version = "devel"`
 #'     installs the current 'development' version.
@@ -287,9 +284,11 @@
 #' `BiocManager::\link{repositories}()` returns the _Bioconductor_ and
 #' CRAN repositories used by `install()`.
 #'
-#' `\link{install.packages}()` installs the packages themselves.
+#' `\link{install.packages}()` installs the packages themselves (used by
+#' `BiocManager::install` internally).
 #'
-#' `\link{update.packages}()` updates all installed packages.
+#' `\link{update.packages}()` updates all installed packages (used by
+#' `BiocManager::install` internally).
 #'
 #' `\link{chooseBioCmirror}()` allows choice of a mirror from all
 #' public _Bioconductor_ mirrors.
@@ -318,7 +317,8 @@
 #' @export
 install <-
     function(pkgs = character(), ..., site_repository = character(),
-        update = TRUE, ask = TRUE, version = BiocManager::version())
+        update = TRUE, ask = TRUE, checkBuilt = FALSE,
+        version = BiocManager::version())
 {
     stopifnot(
         is.character(pkgs), !anyNA(pkgs),
@@ -327,6 +327,7 @@ install <-
         is.character(site_repository), !any(is.na(site_repository)),
         is.logical(update), length(update) == 1L, !is.na(update),
         is.logical(ask), length(ask) == 1L, !is.na(ask),
+        is.logical(checkBuilt), length(checkBuilt) == 1L, !is.na(checkBuilt),
         length(version) == 1L || identical(version, .VERSION_SENTINEL)
     )
     version <- .version_validate(version)
@@ -338,15 +339,22 @@ install <-
 
     cmp <- .version_compare(version, version())
     action <- if (cmp < 0) "Downgrade" else "Upgrade"
-    repos <- repositories(site_repository, version = version)
+    repos <- .repositories(site_repository, version = version)
 
     if (cmp != 0L) {
         pkgs <- unique(c("BiocVersion", pkgs))
-        valist <- .valid(version = version)
-        npkgs <- .install_n_invalid_pkgs(valist)
+        valist <- .valid(
+            site_repository = site_repository, version = version,
+            checkBuilt = checkBuilt
+        )
+        npkgs <- .install_n_invalid_pkgs(valist) + length(pkgs)
         if (!length(pkgs)-1L) {
             .install_ask_up_or_down_grade(version, npkgs, cmp, ask) ||
-                .stop("Bioconductor version not changed")
+                .stop(paste0(
+                    "Bioconductor version not changed by 'install()'",
+                    if (!interactive() && isTRUE(ask))
+                        "; in non-interactive sessions use 'ask = FALSE'"
+                ))
         } else {
             fmt <- paste0(c(
                 "To use Bioconductor version '%s', first %s %d packages with",
@@ -363,9 +371,9 @@ install <-
 
     pkgs <- .install(pkgs, repos = repos, ...)
     if (update && cmp == 0L) {
-        .install_update(repos, ask, ...)
+        .install_update(repos, ask, checkBuilt = checkBuilt, ...)
     } else if (cmp != 0L) {
-        .install_updated_version(valist, update, repos, ask, ...)
+        .install_updated_version(valist, update, repos, ...)
     }
 
     invisible(pkgs)
