@@ -1,3 +1,10 @@
+.is_CRAN_check <-
+    function()
+{
+    opt <- getOption("BIOCMANAGER_CRANCHECK_BEHAVIOR", TRUE)
+    opt && any(grepl("_CRAN_", names(Sys.getenv())))
+}
+
 .getAnswer <- function(msg, allowed)
 {
     if (interactive()) {
@@ -16,6 +23,12 @@
 .sQuote <- function(x)
     sprintf("'%s'", as.character(x))
 
+.url_exists <-
+    function(url)
+{
+    identical(length(.inet_readChar(url, 1L)), 1L)
+}
+
 .msg <-
     function(fmt, ..., width=getOption("width"))
     ## Use this helper to format all error / warning / message text
@@ -43,3 +56,15 @@
     warning(.msg(...), call.=call., immediate.=immediate.)
     invisible(TRUE)
 }
+
+isDevel <-
+    function()
+{
+    version() == .version_bioc("devel")
+}
+
+isRelease <-
+    function()
+{
+    version() == .version_bioc("release")
+}
