@@ -23,11 +23,15 @@ test_that("Helpers filter the right packages", {
 })
 
 test_that(".install_repos() works", {
+    if (any(grepl("_CRAN_", names(Sys.getenv()))))
+        skip("not robust to CRAN internet policy")
     repos <- repositories()
     expect_identical(character(0), .install_repos(character(), repos = repos))
 })
 
 test_that(".install_github() works", {
+    if (any(grepl("_CRAN_", names(Sys.getenv()))))
+        skip("not robust to CRAN internet policy")
     repos <- repositories()
     expect_identical(character(0), .install_github(character(), repos = repos))
 })
